@@ -34,9 +34,6 @@ import constants
 import connection_manager
 
 
-IDLE_TIMEOUT = 10
-
-
 def run_theonering(persist):
 	linux_utils.set_process_name(constants.__app_name__)
 
@@ -60,7 +57,10 @@ def run_theonering(persist):
 	if persist:
 		shutdown_callback = None
 	else:
-		gobject_utils.timeout_add_seconds(IDLE_TIMEOUT, timeout_cb)
+		gobject_utils.timeout_add_seconds(
+			connection_manager.TheOneRingConnectionManager.IDLE_TIMEOUT,
+			timeout_cb
+		)
 		shutdown_callback = on_quit
 
 	signal.signal(signal.SIGTERM, lambda: on_quit)
@@ -91,6 +91,7 @@ def main(logToFile):
 
 	telepathy_utils.debug_divert_messages(os.getenv('THEONERING_LOGFILE'))
 	logFormat = '(%(asctime)s) %(levelname)-5s %(threadName)s.%(name)s: %(message)s'
+	logging.raiseExceptions = True # Getting funky shutdown behavior, checking it out
 	if logToFile:
 		logging.basicConfig(
 			level=logging.DEBUG,
